@@ -6,7 +6,7 @@ require "rabbit/rabbit"
 require 'rabbit/frame'
 require 'rabbit/renderer'
 require 'rabbit/element'
-require "rabbit/rd2rabbit-lib"
+require "rabbit/parser"
 require "rabbit/theme/manager"
 require "rabbit/front"
 require "rabbit/action"
@@ -41,7 +41,7 @@ module Rabbit
     def_delegators(:@renderer, :page_margin_bottom, :page_margin_bottom=)
     def_delegators(:@renderer, :slides_per_page, :slides_per_page=)
     def_delegators(:@renderer, :font_families)
-    def_delegators(:@renderer, :redraw)
+    def_delegators(:@renderer, :redraw, :clear_slide)
     def_delegators(:@renderer, :cursor=, :filename, :filename=)
     def_delegators(:@renderer, :each_slide_pixbuf)
     def_delegators(:@renderer, :off_screen_canvas)
@@ -105,6 +105,7 @@ module Rabbit
     def_delegators(:@renderer, :graffiti_line_width, :graffiti_line_width=)
 
     def_delegators(:@renderer, :toggle_info_window)
+    def_delegators(:@renderer, :toggle_spotlight, :toggle_magnifier)
 
     def_delegators(:@renderer, :add_gesture_action)
 
@@ -139,7 +140,7 @@ module Rabbit
       @quitted = false
       @parse_request_queue = []
       @apply_theme_request_queue = []
-      @auto_reload_timer = nil
+      @auto_redraw_timer = nil
       @output_html = false
       @rss_base_uri = true
       @migemo_dictionary_search_path = []
@@ -199,6 +200,7 @@ module Rabbit
     def slide_title(index=current_index)
       return "" if slides.empty?
       slide = slides[index]
+      return title if slide.nil?
       if slide.is_a?(Element::TitleSlide)
         slide.title
       else
@@ -307,13 +309,42 @@ module Rabbit
       apply_theme(@theme_name, &block)
     end
 
-    def parse_rd(source=nil, callback=nil, &block)
-      _parse_rd(source, Object.new.__id__, callback, &block)
+    def parse(source=nil, callback=nil, &block)
+      id = Object.new.__id__
+      @parse_request_queue.push(id)
+      @source = source || @source
+      begin
+        index = current_index
+        keep_index do
+          @renderer.pre_parse
+          clear
+          Parser.parse(self, @source)
+          set_current_index(index)
+          reload_theme do
+            if @parse_request_queue.last != id
+              raise ParseFinish
+            end
+            callback.call if callback
+          end
+          @renderer.post_parse
+          index = current_index
+        end
+        set_current_index(index)
+      rescue ParseFinish
+      rescue ParseError, UnsupportedFormatError
+        if block_given?
+          yield($!)
+        else
+          logger.warn($!.message)
+        end
+      ensure
+        @parse_request_queue.delete_if {|x| x == id}
+      end
     end
 
     def reload_source(callback=nil, &block)
       if need_reload_source?
-        parse_rd(nil, callback, &block)
+        parse(nil, callback, &block)
       end
     end
 
@@ -331,6 +362,7 @@ module Rabbit
 
     def to_pixbuf(i)
       move_to_if_can(i)
+      current_slide.flush
       @renderer.to_pixbuf(current_slide)
     end
     
@@ -382,10 +414,32 @@ module Rabbit
     end
 
     def move_to_next_if_can
+      slide = current_slide
+      if slide and !slide.last?
+        slide.move_to_next
+        Action.update_status(self)
+        activate("Redraw")
+      else
+        move_to_next_slide_if_can
+      end
+    end
+
+    def move_to_next_slide_if_can
       move_to_if_can(current_index + 1)
     end
 
     def move_to_previous_if_can
+      slide = current_slide
+      if slide and !slide.first?
+        slide.move_to_previous
+        Action.update_status(self)
+        activate("Redraw")
+      else
+        move_to_previous_slide_if_can
+      end
+    end
+
+    def move_to_previous_slide_if_can
       move_to_if_can(current_index - 1)
     end
 
@@ -446,10 +500,18 @@ module Rabbit
       0 < current_index
     end
 
+    def have_previous?
+      have_previous_slide? or (current_slide and !current_slide.first?)
+    end
+
     def have_next_slide?
       slide_size - 1 > current_index
     end
-    
+
+    def have_next?
+      have_next_slide? or (current_slide and !current_slide.last?)
+    end
+
     def cache_all_slides
       process do
         @renderer.cache_all_slides
@@ -460,8 +522,8 @@ module Rabbit
       @processing
     end
 
-    def start_auto_reload_timer(interval)
-      stop_auto_reload_timer
+    def start_auto_redraw_timer(interval)
+      stop_auto_redraw_timer
       timer = GLib::Timeout.add(interval * 1000) do
         if quitted?
           false
@@ -470,17 +532,17 @@ module Rabbit
           true
         end
       end
-      @auto_reload_timer = timer
+      @auto_redraw_timer = timer
     end
 
-    def stop_auto_reload_timer
-      if @auto_reload_timer
+    def stop_auto_redraw_timer
+      if @auto_redraw_timer
         if GLib::Source.respond_to?(:remove)
-          GLib::Source.remove(@auto_reload_timer)
+          GLib::Source.remove(@auto_redraw_timer)
         else
-          Gtk.timeout_remove(@auto_reload_timer)
+          Gtk.timeout_remove(@auto_redraw_timer)
         end
-        @auto_reload_timer = nil
+        @auto_redraw_timer = nil
       end
     end
 
@@ -554,6 +616,10 @@ module Rabbit
       @limit_time ? @limit_time - Time.now : nil
     end
 
+    def reset_timer
+      @limit_time = nil
+    end
+
     private
     def _apply_theme(name, id, &block)
       @theme_name = name if name
@@ -584,44 +650,6 @@ module Rabbit
       end
     end
 
-    def _parse_rd(source, id, callback, &block)
-      @parse_request_queue.push(id)
-      @source = source || @source
-      begin
-        index = current_index
-        keep_index do
-          @renderer.pre_parse_rd
-          __parse_rd
-          set_current_index(index)
-          reload_theme do
-            if @parse_request_queue.last != id
-              raise ParseFinish
-            end
-            callback.call if callback
-          end
-          @renderer.post_parse_rd
-          index = current_index
-        end
-        set_current_index(index)
-      rescue ParseFinish
-      rescue Racc::ParseError
-        if block_given?
-          yield($!)
-        else
-          logger.warn($!.message)
-        end
-      ensure
-        @parse_request_queue.delete_if {|x| x == id}
-      end
-    end
-
-    def __parse_rd
-      clear
-      tree = RD::RDTree.new("=begin\n#{@source.read}\n=end\n")
-      visitor = RD2RabbitVisitor.new(self)
-      visitor.visit(tree)
-    end
-
     def process
       if @processing
         @logger.info(_("Processing..."))
@@ -631,11 +659,6 @@ module Rabbit
         @processing = true
         Action.update_status(self)
         yield
-      rescue Exception
-        puts $!.class
-        puts $!
-        puts $@
-        raise
       ensure
         @processing = false
         Action.update_status(self)
@@ -647,7 +670,8 @@ module Rabbit
     end
     
     def clear
-      stop_auto_reload_timer
+      reset_timer
+      stop_auto_redraw_timer
       clear_slides
       clear_index_slides
       modified
