@@ -31,7 +31,9 @@ module Rabbit
       attr_accessor :default_padding_left, :default_padding_right
       attr_accessor :default_padding_top, :default_padding_bottom
 
-      attr_accessor :parent
+      attr_accessor :default_visible
+
+      attr_reader :parent, :real_simulation
 
       def initialize
         @x = @y = @w = @h = nil
@@ -40,9 +42,23 @@ module Rabbit
         @default_prop = {}
         init_default_padding
         init_default_margin
+        init_default_visible
         clear_theme
       end
 
+      def parent=(parent)
+        @slide = nil
+        @parent = parent
+      end
+
+      def visible?
+        @visible
+      end
+
+      def slide
+        @slide ||= _slide
+      end
+
       def draw(simulation=false)
         x, y, w, h = setup_padding(@x, @y, @w, @h)
         x, y, w, h = _draw(@canvas, x, y, w, h, simulation)
@@ -62,6 +78,14 @@ module Rabbit
         @dirty
       end
 
+      def wait(*args, &block)
+        slide.register_wait_proc(self, *args, &block) if slide
+      end
+
+      def have_wait_tag?
+        false
+      end
+
       def compile(canvas, x, y, w, h)
         @base_x, @base_y, @base_w, @base_h = x, y, w, h
         @px, @py, @pw, @ph = @x, @y, @w, @h
@@ -126,7 +150,16 @@ module Rabbit
         false
       end
 
+      def substitute_newline
+        substitute_text do |text|
+          text.gsub(/(\\)?\\n/) {$1 ? "\\n" : "\n"}
+        end
+      end
+
       def clear_theme
+        @slide = nil
+        @visible = @default_visible
+        @real_simulation = true
         @width = @height = nil
         @centering_adjusted_width = nil
         @centering_adjusted_height = nil
@@ -198,6 +231,10 @@ module Rabbit
         @default_margin_bottom = 0
       end
 
+      def init_default_visible
+        @default_visible = !have_wait_tag?
+      end
+
       def clear_padding
         @padding_left = @default_padding_left
         @padding_right = @default_padding_right
@@ -295,7 +332,7 @@ module Rabbit
       end
 
       def margin_set(*values)
-        top, right, bottom, left = parse_four_dimensions(*values)
+        top, right, bottom, left = parse_four_way(*values)
         @margin_top = top if top
         @margin_right = right if right
         @margin_bottom = bottom if bottom
@@ -303,11 +340,11 @@ module Rabbit
       end
 
       def margin_with(params)
-        margin_set(*extract_four_dimensions(params))
+        margin_set(params)
       end
 
       def padding_set(*values)
-        top, right, bottom, left = parse_four_dimensions(*values)
+        top, right, bottom, left = parse_four_way(*values)
         @padding_top = top if top
         @padding_right = right if right
         @padding_bottom = bottom if bottom
@@ -315,7 +352,15 @@ module Rabbit
       end
 
       def padding_with(params)
-        padding_set(*extract_four_dimensions(params))
+        padding_set(*extract_four_way(params))
+      end
+
+      def show(&block)
+        change_visible(true, &block)
+      end
+
+      def hide(&block)
+        change_visible(false, &block)
       end
 
       protected
@@ -328,6 +373,26 @@ module Rabbit
       end
 
       private
+      def _slide
+        if @parent
+          @parent.slide
+        else
+          nil
+        end
+      end
+
+      def change_visible(value)
+        visible = @visible
+        @visible = value
+        if block_given?
+          begin
+            yield
+          ensure
+            @visible = visible
+          end
+        end
+      end
+
       def make_prop_value(name, *values)
         formatter_name = to_class_name(name)
         begin
@@ -385,30 +450,41 @@ module Rabbit
       end
 
       def _draw(canvas, x, y, w, h, simulation)
-        _draw_rec(canvas, x, y, w, h, simulation, @around_draw_procs.size)
+        around_draw_procs = @around_draw_procs.dup
+        around_draw_procs.concat(slide.waited_draw_procs(self))
+        _draw_rec(canvas, x, y, w, h, simulation, around_draw_procs)
       end
 
-      def _draw_rec(canvas, x, y, w, h, simulation, around_index)
-        if around_index.zero?
+      def _draw_rec(canvas, x, y, w, h, simulation, around_draw_procs)
+        if around_draw_procs.empty?
           (@pre_draw_procs +
            [method(:draw_element)] +
            @post_draw_procs.reverse).each do |pro,|
-            x, y, w, h = pro.call(canvas, x, y, w, h, simulation)
+            @real_simulation = simulation
+            _simulation = simulation
+            _simulation = true unless visible?
+            x, y, w, h = pro.call(canvas, x, y, w, h, _simulation)
           end
           [x, y, w, h]
         else
-          pro, = @around_draw_procs[around_index - 1]
-          pro.call(canvas, x, y, w, h, simulation, Proc.new do |*args|
-            args << around_index - 1
+          @real_simulation = simulation
+          _simulation = simulation
+          _simulation = true unless visible?
+          pro, = around_draw_procs.pop
+          next_proc = Proc.new do |*args|
+            args << around_draw_procs
             _draw_rec(*args)
-          end)
+          end
+          pro.call(canvas, x, y, w, h, _simulation, next_proc)
         end
       end
 
       def _indent(str, width="  ")
-        str.collect do |x|
-          width + x
-        end.join("")
+        result = ""
+        str.each_line do |line|
+          result << width + line
+        end
+        result
       end
     end
   end
