@@ -12,6 +12,7 @@ module Rabbit
       attr_reader :elements
 
       def_delegators(:@elements, :[], :empty?, :each, :first, :last)
+      def_delegators(:@elements, :size, :length)
 
       def initialize(elems=[])
         @elements = []
@@ -35,6 +36,13 @@ module Rabbit
         dirty!
       end
 
+      def delete(element)
+        return if @elements.delete(element).nil?
+        element.parent = nil
+        dirty!
+        element
+      end
+
       def text
         @elements.collect do |element|
           element.text
@@ -220,6 +228,10 @@ module Rabbit
         end
         self_info + (elem_info.empty? ? "" : "\n") + elem_info
       end
+
+      def have_wait_tag?
+        @elements.any? {|element| element.have_wait_tag?}
+      end
     end
   end
 end
