@@ -21,6 +21,9 @@ module Rabbit
       end
 
       def align=(new_value)
+        if new_value.is_a?(String)
+          new_value = Pango::Layout.const_get("ALIGN_#{new_value.to_s.upcase}")
+        end
         dirty! if @align != new_value
         @align = new_value
       end
@@ -258,6 +261,7 @@ module Rabbit
         unless compare.call(*@layout.pixel_size)
           loop do
             new_size = compute_next_font_size(size, scale)
+            break if new_size == size
             set_computed_font_size(new_size)
             compile(canvas, x, y, w, h)
             break if compare.call(*@layout.pixel_size)
