@@ -27,6 +27,9 @@ module Rabbit
               end
             end
           end
+          false
+        rescue ArgumentError
+          false
         end
       end
       
