@@ -56,7 +56,7 @@ module Rabbit
 
     def make_jump_to_action(jump_to_action, title, i)
       name = "JumpTo#{i}"
-      label = "#{i}: #{Utils.unescape_title(title)}"
+      label = "#{i}: #{escape_label(Utils.unescape_title(title))}"
       tooltip = _("Jump to the %dth slide") % i
       action = Gtk::Action.new(name, label, tooltip, nil)
       action.signal_connect("activate") do
@@ -65,12 +65,17 @@ module Rabbit
       action
     end
 
+    def escape_label(label)
+      label.gsub(/_/, '__')
+    end
+
     def update_jump_to_menu(canvas)
       @merge.remove_ui(@jump_to_merge_id) if @jump_to_merge_id
       @merge.remove_action_group(@jump_to_actions) if @jump_to_actions
 
       @jump_to_merge_id = @merge.new_merge_id
       @jump_to_actions = Gtk::ActionGroup.new("JumpToActions")
+      @jump_to_actions_keeper = [] # Workaround for > Ruby/GTK2 0.16
       @merge.insert_action_group(@jump_to_actions, 0)
       jump_to_path = "/popup/JumpTo"
       jump_to_action = canvas.action("JumpTo")
@@ -78,6 +83,7 @@ module Rabbit
       canvas.slides.each_with_index do |slide, i|
         action = make_jump_to_action(jump_to_action, slide.title, i)
         @jump_to_actions.add_action(action)
+        @jump_to_actions_keeper << action # Workaround for > Ruby/GTK2 0.16
         @merge.add_ui(@jump_to_merge_id, jump_to_path, action.name,
                       action.name, Gtk::UIManager::AUTO, false)
       end
@@ -235,9 +241,14 @@ module Rabbit
 #         [:separator],
 #         [:item, "ToggleCommentFrame"],
 #         [:item, "ToggleCommentView"],
+        [:separator],
+        [:item, "ToggleSpotlight"],
+        [:item, "ToggleMagnifier"],
         [:separator],
         [:menu, "JumpTo"],
         [:separator],
+        [:item, "Previous"],
+        [:item, "Next"],
         [:item, "PreviousSlide"],
         [:item, "NextSlide"],
         [:item, "FirstSlide"],
@@ -246,6 +257,7 @@ module Rabbit
         [:item, "Iconify"],
         [:separator],
         [:item, "Redraw"],
+        [:item, "ClearSlide"],
         [:item, "ReloadTheme"],
         [:menu, "ChangeTheme"],
         [:menu, "MergeTheme"],
@@ -255,8 +267,18 @@ module Rabbit
         [:item, "SaveAsImage"],
         [:item, "Print"],
         [:separator],
+        [:item, "ResetTimer"],
         [:item, "ResetAdjustment"],
         [:separator],
+        [:menu, "LogLevel",
+          [:item, "RadioLogLevelDebug"],
+          [:item, "RadioLogLevelInfo"],
+          [:item, "RadioLogLevelWarning"],
+          [:item, "RadioLogLevelError"],
+          [:item, "RadioLogLevelFatal"],
+          [:item, "RadioLogLevelUnknown"],
+        ],
+        [:separator],
         [:item, "Quit"],
       ]
     end
