@@ -8,7 +8,7 @@ require "rabbit/gettext"
 
 module Rabbit
 
-  VERSION = "0.5.0"
+  VERSION = "0.5.7"
 
   TMP_DIR_NAME = ".tmp"
 
@@ -82,17 +82,9 @@ module Rabbit
     end
   end
 
-  class TgifCanNotHandleError < ImageLoadWithExternalCommandError
-    def initialize(command, tried_commands)
-      format = _("tried tgif commands: %s")
-      additional_info = format % tried_commands.inspect
-      super("Tgif", command, additional_info)
-    end
-  end
-
   class TeXCanNotHandleError < ImageLoadWithExternalCommandError
-    def initialize(command)
-      super("TeX", command)
+    def initialize(command, additional_info=nil)
+      super("TeX", command, additional_info)
     end
   end
 
@@ -209,6 +201,12 @@ module Rabbit
   class ParseFinish < Error
   end
 
+  class ParseError < Error
+  end
+
+  class UnsupportedFormatError < Error
+  end
+
   class ApplyFinish < Error
   end
 
