@@ -111,6 +111,11 @@ module Rabbit
       def redraw
       end
 
+      def clear_slide
+        current = @canvas.current_slide
+        current.clear_waiting if current
+      end
+
       def reset_adjustment
         @adjustment_x = 0
         @adjustment_y = 0
@@ -242,6 +247,9 @@ module Rabbit
       def toggle_info_window
       end
 
+      def toggle_spotlight
+      end
+
       def toggle_comment_frame
       end
 
@@ -324,7 +332,9 @@ module Rabbit
         canceled = false
         @canvas.slides.each_with_index do |slide, i|
           @canvas.move_to_if_can(i)
-          @canvas.current_slide.draw(@canvas)
+          current_slide = @canvas.current_slide
+          current_slide.flush
+          current_slide.draw(@canvas)
           if block and !block.call(i)
             canceled = true
             break
@@ -338,7 +348,7 @@ module Rabbit
         yield canvas
         canvas.apply_theme(@canvas.theme_name)
         @canvas.source_force_modified(true) do |source|
-          canvas.parse_rd(source)
+          canvas.parse(source)
         end
         canvas.toggle_index_mode if @canvas.index_mode?
         canvas
