@@ -49,7 +49,9 @@ module Rabbit
               first_move = !@gesture.moved?
               handled = @gesture.button_motion(event.x, event.y, width, height)
               queue_draw if handled or first_move
-              @gesture.draw_last_locus(@drawable)
+              init_renderer(@drawable)
+              @gesture.draw_last_locus(self)
+              finish_renderer
               true
             else
               false
@@ -60,9 +62,9 @@ module Rabbit
         def init_gesture_actions
           @gesture.clear_actions
           bg_proc = Utils.process_pending_events_proc
-          add_gesture_action(%w(R), "NextSlide")
+          add_gesture_action(%w(R), "Next")
           add_gesture_action(%w(R L), "LastSlide")
-          add_gesture_action(%w(L), "PreviousSlide")
+          add_gesture_action(%w(L), "Previous")
           add_gesture_action(%w(L R), "FirstSlide")
           add_gesture_action(%w(U), "Quit")
 
@@ -83,7 +85,7 @@ module Rabbit
         end
 
         def draw_gesture
-          @gesture.draw(@drawable) if gesturing? and @gesture.moved?
+          @gesture.draw(self) if gesturing? and @gesture.moved?
         end
       end
     end
