@@ -98,11 +98,11 @@ module Rabbit
           end
           keys = Keys::MOVE_TO_NEXT_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
-            @canvas.activate("NextSlide")
+            @canvas.activate("Next")
           end
           keys = Keys::MOVE_TO_PREVIOUS_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
-            @canvas.activate("PreviousSlide")
+            @canvas.activate("Previous")
           end
           keys = Keys::MOVE_TO_FIRST_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
@@ -207,9 +207,9 @@ module Rabbit
             @canvas.activate("UndoGraffiti")
           end
 
-          keys = Keys::Control::REDRAW_KEYS
+          keys = Keys::Control::CLEAR_SLIDE_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
-            @canvas.activate("Redraw")
+            @canvas.activate("ClearSlide")
           end
           keys = Keys::Control::PRINT_KEYS
           set_keys(keys, mod) do |group, obj, val, modifier|
@@ -235,6 +235,15 @@ module Rabbit
           set_keys(keys, mod) do |group, obj, val, modifier|
             @canvas.activate("StopSlideSearch")
           end
+
+          keys = Keys::MOVE_TO_NEXT_KEYS
+          set_keys(keys, mod) do |group, obj, val, modifier|
+            @canvas.activate("NextSlide")
+          end
+          keys = Keys::MOVE_TO_PREVIOUS_KEYS
+          set_keys(keys, mod) do |group, obj, val, modifier|
+            @canvas.activate("PreviousSlide")
+          end
         end
 
         def init_alt_keys
@@ -244,6 +253,11 @@ module Rabbit
           set_keys(keys, mod) do |group, obj, val, modifier|
             @canvas.activate("ResetAdjustment")
           end
+
+          keys = Keys::Alt::RESET_TIMER_KEYS
+          set_keys(keys, mod) do |group, obj, val, modifier|
+            @canvas.activate("ResetTimer")
+          end
         end
 
         def set_key_press_event(widget)
