@@ -50,12 +50,18 @@ module Rabbit
             Gdk.respond_to?(:cairo_available?) and Gdk.cairo_available?
           end
 
+          def available_with_gdk_pixbuf?
+            Gdk::Pixbuf.respond_to?(:cairo_available?) and
+              Gdk::Pixbuf.cairo_available?
+          end
+
           def available_with_pango?
             Pango.respond_to?(:cairo_available?) and Pango.cairo_available?
           end
 
           def priority
-            if available_with_gdk? and available_with_pango?
+            if available_with_gdk? and available_with_gdk_pixbuf? and
+                available_with_pango?
               100
             else
               -100
@@ -63,17 +69,34 @@ module Rabbit
           end
         end
 
-        attr_writer :foreground, :background, :background_image
+        attr_writer :foreground, :background
 
         def alpha_available?
           true
         end
 
+        def background_image=(pixbuf)
+          surface = ::Cairo::ImageSurface.new(::Cairo::FORMAT_A1, 1, 1)
+          context = ::Cairo::Context.new(surface)
+          context.set_source_pixbuf(pixbuf)
+          @background_image = context.source
+          @background_image.extend = ::Cairo::EXTEND_REPEAT
+          pixbuf
+        end
+
         def init_renderer(drawable)
+          @contexts ||= []
           @context = drawable.create_cairo_context
+          @contexts.push(@context)
           init_context
         end
 
+        def finish_renderer
+          @contexts.pop
+          @context.destroy if @context.respond_to?(:destroy)
+          @context = @contexts.pop
+        end
+
         def init_context
           set_line_width(1)
           @context.line_cap = ::Cairo::LINE_CAP_ROUND
@@ -122,6 +145,16 @@ module Rabbit
           @context.restore
         end
 
+        def draw_background(slide)
+          super
+          if @background_image
+            @context.save do
+              @context.set_source(@background_image)
+              @context.paint
+            end
+          end
+        end
+
         def draw_line(x1, y1, x2, y2, color=nil, params={})
           x1, y1 = from_screen(x1, y1)
           x2, y2 = from_screen(x2, y2)
@@ -269,6 +302,10 @@ module Rabbit
           layout
         end
 
+        def create_pango_context
+          Pango::CairoFontMap.default.create_context
+        end
+
         private
         def init_engine_color
           @foreground = make_color("black")
@@ -294,15 +331,15 @@ module Rabbit
             cx1, cy1 = from_screen(cx1, cy1)
             pattern = ::Cairo::RadialPattern.new(cx0, cy0, radius0,
                                                  cx1, cy1, radius1)
-            info[:color_stops].each do |rgba|
-              pattern.add_color_stop_rgba(*rgba)
+            info[:color_stops].each do |offset, r, g, b, a|
+              pattern.add_color_stop_rgba(offset, r, g, b, a)
             end
           when :linear
             x, y, w, h = info[:base]
             x, y = from_screen(x, y)
             pattern = ::Cairo::LinearPattern.new(x, y, w, h)
-            info[:color_stops].each do |rgba|
-              pattern.add_color_stop_rgba(*rgba)
+            info[:color_stops].each do |offset, r, g, b, a|
+              pattern.add_color_stop_rgba(offset, r, g, b, a)
             end
           end
           @context.set_source(pattern) if pattern
