@@ -43,10 +43,10 @@ module Rabbit
           @context.target.finish
         end
         
-        def pre_parse_rd
+        def pre_parse
         end
         
-        def post_parse_rd
+        def post_parse
         end
         
         def post_apply_theme
@@ -83,23 +83,35 @@ module Rabbit
         end
 
         def init_context
-          surface = find_surface(filename)
-          surface.set_fallback_resolution(@x_dpi, @y_dpi)
-          @context = ::Cairo::Context.new(surface)
+          @context = create_context
           super
         end
 
-        def find_surface(filename)
+        def create_context(output=nil)
+          surface = find_surface(filename, output)
+          surface.set_fallback_resolution(@x_dpi, @y_dpi)
+          ::Cairo::Context.new(surface)
+        end
+
+        def create_pango_context
+          create_context(StringIO.new).create_pango_layout.context
+        end
+
+        def find_surface(filename, output=nil)
+          args = [output || filename, @page_width, @page_height]
           case File.extname(filename)
           when /\.ps/i
-            ::Cairo::PSSurface.new(filename, @page_width, @page_height)
+            ::Cairo::PSSurface.new(*args)
           when /\.pdf/i
-            ::Cairo::PDFSurface.new(filename, @page_width, @page_height)
+            ::Cairo::PDFSurface.new(*args)
           when /\.svg/i
-            ::Cairo::SVGSurface.new(filename, @page_width, @page_height)
+            surface = ::Cairo::SVGSurface.new(*args)
+            surface.restrict_to_version(::Cairo::SVG_VERSION_1_2)
+            surface
           else
             @canvas.logger.warn(_("can't find printer for %s") % filename)
-            ::Cairo::PSSurface.new("default.ps", @page_width, @page_height)
+            args[0] = "default.ps"
+            ::Cairo::PSSurface.new(*args)
           end
         end
       end
