@@ -9,7 +9,7 @@ require 'rabbit/renderer/color'
 
 module Rabbit
   module Theme
-    class ElementContainer < DelegateClass(Array)
+    class ElementContainer < Array
       def initialize(applier, ary)
         @applier = applier
         super(ary)
@@ -192,7 +192,7 @@ module Rabbit
       end
 
       def method_missing(meth, *args, &block)
-        each do |elem|
+        collect do |elem|
           if block
             proxy_block = Proc.new do |*block_args|
               block.call(elem, *block_args)
@@ -212,8 +212,9 @@ module Rabbit
 
       extend Forwardable
 
-      logger_methods = [:debug, :info, :warn, :error, :fatal, :unknown]
+      logger_methods = [:debug, :info, :warning, :error, :fatal, :unknown]
       def_delegators(:logger, *logger_methods)
+      def_delegators(:logger, :warn) # for backward compatibility
       private *logger_methods
 
       def_delegators(:canvas, :make_layout)
@@ -323,8 +324,8 @@ module Rabbit
         canvas.background_image = loader.pixbuf
       end
 
-      def set_progress_foreground(color)
-        canvas.progress_foreground = canvas.make_color(color)
+      def set_progress_foreground(*color)
+        canvas.progress_foreground = canvas.make_color(*color)
       end
 
       def set_progress_background(color)
@@ -369,10 +370,17 @@ module Rabbit
         Utils.windows?
       end
 
+      def quartz?
+        Utils.quartz?
+      end
+
       def match(*paths, &block)
         dirty
+        targets = _match(slides, *paths)
+        return if targets.empty?
+
         begin
-          @current_target = make_container(_match(slides, *paths))
+          @current_target = make_container(targets)
           block.call(@current_target)
         ensure
           @current_target = nil
@@ -391,6 +399,7 @@ module Rabbit
         last_path_index = paths.size - 1
         paths.each_with_index do |path, i|
           current = _match_with_cache(current, path, i == last_path_index) do
+            current = ignore_wait_block(current) unless i == last_path_index
             if path.nil?
               slides
             elsif path == "**"
@@ -443,6 +452,16 @@ module Rabbit
         end
       end
 
+      def ignore_wait_block(elements)
+        elements.inject([]) do |result, element|
+          if element.is_a?(WaitBlock)
+            result + ignore_wait_block(element.elements)
+          else
+            result + [element]
+          end
+        end
+      end
+
       def normalized_width
         (canvas.x_dpi / 72.0) * NORMALIZED_WIDTH
       end
@@ -519,28 +538,33 @@ module Rabbit
         yield [to_container(targets), args]
       end
 
-      def start_auto_reload_timer(interval)
-        canvas.start_auto_reload_timer(interval)
+      def start_auto_redraw_timer(interval)
+        canvas.start_auto_redraw_timer(interval)
       end
-
-      def stop_auto_reload_timer
-        canvas.stop_auto_reload_timer
+      def stop_auto_redraw_timer
+        canvas.stop_auto_redraw_timer
       end
 
       # For backward compatibility
+      def start_auto_reload_timer(interval)
+        deprecated_method("start_auto_redraw_timer",
+                          "start_auto_reload_timer")
+        canvas.start_auto_redraw_timer(interval)
+      end
+      def stop_auto_reload_timer
+        deprecated_method("stop_auto_redraw_timer",
+                          "stop_auto_reload_timer")
+        canvas.stop_auto_redraw_timer
+      end
       def start_auto_reload_thread(interval)
-        format = _("%s is deprecated. Use %s instead.")
-        message = format % ["start_auto_reload_thread",
-                            "start_auto_reload_timer"]
-        warn(message)
-        start_auto_reload_timer(interval)
+        deprecated_method("start_auto_redraw_timer",
+                          "start_auto_reload_thread")
+        start_auto_redraw_timer(interval)
       end
       def stop_auto_reload_thread
-        format = _("%s is deprecated. Use %s instead.")
-        message = format % ["stop_auto_reload_thread",
-                            "stop_auto_reload_timer"]
-        warn(message)
-        stop_auto_reload_timer
+        deprecated_method("stop_auto_redraw_timer",
+                          "stop_auto_reload_thread")
+        stop_auto_redraw_timer
       end
 
       def dirtied
@@ -557,6 +581,24 @@ module Rabbit
       def disconnect_key(keyval, modifier=nil)
         canvas.disconnect_key(keyval, modifier)
       end
+
+      def deprecated_method(current, deprecated)
+        format = _("%s is deprecated. Use %s instead.")
+        message = format % [deprecated, current]
+        warning(message)
+      end
+
+      def tag(name, attributes, content)
+        "<#{name} #{to_attrs(attributes)}>#{content}</#{name}>"
+      end
+
+      def span(attributes, content)
+        tag("span", attributes, content)
+      end
+
+      def entity(key)
+        Parser::Ext::Entity::TABLE[key]
+      end
     end
   end
 end
