@@ -17,6 +17,9 @@
 @margin_top = screen_y(3)
 @margin_bottom = screen_y(3)
 
+@body_margin_left = screen_x(3)
+@body_margin_right = screen_x(3)
+
 @table_frame_color = "#55003dff0eff"
 @table_fill_color = "#fcfae2"
 
@@ -57,12 +60,17 @@
 @font_family = nil
 @monospace_font_family = nil
 
+@font_family = find_font_family("Rabbit")
+@monospace_font_family = find_font_family("Rabbit Monospace")
+
 if windows?
-  @font_family = "ms pgothic" if font_families.include?("ms pgothic")
-  @monospace_font_family = "ms gothic" if font_families.include?("ms gothic")
-else
-  @font_family = find_font_family("Rabbit")
-  @font_family ||= find_font_family("Sans")
-  @monospace_font_family = find_font_family("Rabbit Monospace")
-  @monospace_font_family ||= find_font_family("Monospace")
+  @font_family ||= find_font_family("MS PGothic")
+  @monospace_font_family ||= find_font_family("MS Gothic")
+elsif quartz?
+  @font_family ||= find_font_family("Hiragino Kaku Gothic Pro")
+  @monospace_font_family ||= find_font_family("Osaka-Mono")
+  @monospace_font_family ||= find_font_family("Osaka")
 end
+
+@font_family ||= find_font_family("Sans")
+@monospace_font_family ||= find_font_family("Monospace")
