@@ -1,3 +1,9 @@
+@default_foreground ||= "black"
+@default_background ||= "white"
+
+set_foreground(@default_foreground)
+set_background(@default_background)
+
 add_image_path("ruby-images")
 include_theme("image")
 include_theme("table")
@@ -13,4 +19,3 @@ include_theme("default-preformatted")
 include_theme("default-block-quote")
 include_theme("default-foot-text")
 include_theme("default-description")
-include_theme("windows-adjust")
