@@ -6,11 +6,19 @@ proc_name = "image-slide-number"
 @image_slide_number_show_text ||= false
 @image_slide_number_font_size ||= @xx_small_font_size
 @image_slide_number_text_color ||= "white"
+if !defined?(@image_slide_number_show_flag) or
+    @image_slide_number_show_flag.nil?
+  @image_slide_number_show_flag = true
+end
 @image_slide_number_flag_type ||= "rectangle"
 @image_slide_number_start_image ||= "start-flag.png"
 @image_slide_number_goal_image ||= "goal-flag.png"
 @image_slide_number_space_ratio ||= 1.0 / 12.0
 
+@image_slide_number_margin_left ||= nil
+@image_slide_number_margin_right ||= nil
+@image_slide_number_margin_bottom ||= nil
+
 match(Slide) do |slides|
   slides.delete_post_draw_proc_by_name(proc_name)
   
@@ -56,27 +64,32 @@ match(Slide) do |slides|
         goal_flag_width = goal_loader.width
       end
     else
-      base_x = slide.margin_left
-      base_y = canvas.height - loader.height - slide.margin_bottom
-      max_width = canvas.width - slide.margin_left - base_x - loader.width
+      margin_left = @image_slide_number_margin_left || slide.margin_left
+      margin_right = @image_slide_number_margin_right || slide.margin_right
+      margin_bottom = @image_slide_number_margin_bottom || slide.margin_bottom
+      base_x = margin_left
+      base_y = canvas.height - loader.height - margin_bottom
+      max_width = canvas.width - margin_left - base_x - loader.width
       start_base_x = base_x
-      goal_base_x = canvas.width - slide.margin_right - goal_flag_width
+      goal_base_x = canvas.width - margin_right - goal_flag_width
 
-      if @image_slide_number_show_text
-        props = {
-          "flag_type" => @image_slide_number_flag_type,
-          "text" => "%0#{max_text_length}d" % canvas.current_index.to_s,
-          "text_attributes" => text_attributes,
-          "flag_color" => "red",
-        }
-        canvas.draw_flag(start_base_x, base_y, loader.height, props)
+      if @image_slide_number_show_flag
+        if @image_slide_number_show_text
+          props = {
+            "flag_type" => @image_slide_number_flag_type,
+            "text" => "%0#{max_text_length}d" % canvas.current_index.to_s,
+            "text_attributes" => text_attributes,
+            "flag_color" => "red",
+          }
+          canvas.draw_flag(start_base_x, base_y, loader.height, props)
 
-        props["text"] = (canvas.slide_size - 1).to_s
-        props["flag_color"] = "blue"
-        canvas.draw_flag(goal_base_x, base_y, loader.height, props)
-      else
-        start_loader.draw(canvas, start_base_x, base_y)
-        goal_loader.draw(canvas, goal_base_x, base_y)
+          props["text"] = (canvas.slide_size - 1).to_s
+          props["flag_color"] = "blue"
+          canvas.draw_flag(goal_base_x, base_y, loader.height, props)
+        else
+          start_loader.draw(canvas, start_base_x, base_y)
+          goal_loader.draw(canvas, goal_base_x, base_y)
+        end
       end
 
       if canvas.slide_size < 3
