@@ -24,11 +24,15 @@ end
 @image_timer_interval ||= 5
 @image_timer_space_ratio ||= 1.0 / 12.0
 
+@image_timer_margin_left ||= nil
+@image_timer_margin_right ||= nil
+@image_timer_margin_bottom ||= nil
+
 @image_time_auto_updating = false
 
 match(Slide) do |slides|
   slides.delete_post_draw_proc_by_name(proc_name)
-  stop_auto_reload_timer
+  stop_auto_redraw_timer
 
   break if @image_timer_uninstall
 
@@ -38,7 +42,7 @@ match(Slide) do |slides|
       canvas.start_timer(@image_timer_limit) if canvas.rest_time.nil?
       if @image_timer_auto_update && !@image_timer_auto_updating
         @image_timer_auto_updating = true
-        start_auto_reload_timer(@image_timer_interval)
+        start_auto_redraw_timer(@image_timer_interval)
       end
       slide.delete_post_draw_proc_by_name(init_proc_name)
     end
@@ -51,16 +55,20 @@ match(Slide) do |slides|
   base_y = nil
 
   slides.add_post_draw_proc(proc_name) do |slide, canvas, x, y, w, h, simulation|
+    margin_left = @image_timer_margin_left || slide.margin_left
+    margin_right = @image_timer_margin_right || slide.margin_right
+    margin_bottom = @image_timer_margin_bottom || slide.margin_bottom
+
     if simulation
       image_height = canvas.height * @image_timer_space_ratio
       loader.resize(nil, image_height)
-      max_width = canvas.width - slide.margin_left
-      max_width = max_width - slide.margin_right - loader.width
-      base_y = canvas.height - slide.margin_bottom - loader.height
+      max_width = canvas.width - margin_left
+      max_width = max_width - margin_right - loader.width
+      base_y = canvas.height - margin_bottom - loader.height
     else
       rest_time = canvas.rest_time
       ratio = 1 - (rest_time.to_i / @image_timer_limit.to_f)
-      base_x = slide.margin_left + max_width * ratio
+      base_x = margin_left + max_width * ratio
 
       loader.draw(canvas, base_x, base_y)
 
